(use-local-map im-local-map)
(setq lc-jp 14)
(skk-mode)
(make-local-hook 'post-command-hook)
(add-hook 'post-command-hook 'im-auto-send-text t t)
;(princ skk-mode-hook)
;(princ post-command-hook)
